(-doEncode this event)Encode a LoggingEvent to JSON bytes
Encode a LoggingEvent to JSON bytes
(-init)Initialize the encoder with an empty state atom
Initialize the encoder with an empty state atom
(extract-exception-info event)Extracts exception information with full stack traces
Extracts exception information with full stack traces
(extract-full-exception-chain throwable-proxy)Extracts complete exception chain with all causes and stack traces
Extracts complete exception chain with all causes and stack traces
(parse-edn-safely message)Safely parse EDN string, returning structured data or error info
Safely parse EDN string, returning structured data or error info
(parse-edn-value-safely value)Tries to parse a string as EDN
Tries to parse a string as EDN
(prepare-for-json data)Converts some problematic java types
Converts some problematic java types
(safe-get-mdc-with-edn-parsing event preserve-originals?)Gets MDC context and parses it
Gets MDC context and parses it
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |